<?php
/**
 * Functions for configuring demo importer.
 *
 * @package Importer/Functions
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Setup demo importer config.
 *
 * @deprecated 1.5.0
 *
 * @param  array $demo_config Demo config.
 *
 * @return array
 */
function accelerate_demo_importer_config( $demo_config ) {
	$new_demo_config = array(
		'accelerate-pro'  => array(
			'name'                   => __( 'Accelerate Pro', 'accelerate' ),
			'demo_url'               => 'http://demo.themegrill.com/accelerate-pro/',
			'demo_pack'              => false,
			'theme'                  => 'Accelerate Pro',
			'template'               => 'accelerate-pro',
			'core_options'           => array(
				'blogname'       => 'Accelerate Pro',
				'page_on_front'  => 'Home',
				'page_for_posts' => 'Blog',
			),
			'widgets_data_update'    => array(

				/**
				 * Dropdown Pages - Handles widgets Page ID.
				 *
				 * 1. accelerate_image_service_widget
				 * 2. accelerate_team_widget
				 * 3. accelerate_recent_work_widget
				 */
				'dropdown_pages'      => array(
					'accelerate_image_service_widget' => array(
						2 => array(
							'page_id0' => 'Nice Support',
							'page_id1' => 'Cool Design',
							'page_id2' => 'Clean Code',
						),
					),
					'accelerate_team_widget'          => array(
						3 => array(
							'page_0' => 'Amanda Hayes',
							'page_1' => 'Brandon Reed',
							'page_2' => 'Shirley King',
						),
					),
					'accelerate_recent_work_widget'   => array(
						2 => array(
							'page_id0' => 'Skating',
							'page_id1' => 'Reading Books',
							'page_id2' => 'Photography',
							'page_id3' => 'Spectacle',
						),
					),
				),

				/**
				 * Dropdown Categories - Handles widgets Category ID.
				 *
				 * A. Core Post Category:
				 *    1. accelerate_featured_posts_widget
				 *
				 * Note: Supported Taxonomy:
				 *    A. Core Post Category - category
				 */
				'dropdown_categories' => array(
					'category' => array(
						'accelerate_featured_posts_widget' => array(
							2 => array(
								'category' => 'Featured',
							),
						),
					),
				),
			),
			'customizer_data_update' => array(
				'nav_menu_locations' => array(
					'primary' => 'Primary',
					'header'  => 'Header',
					'footer'  => 'Footer',
				),
			),
			'plugins_list'           => array(
				'everest-forms'      => array(
					'name'     => __( 'Everest Forms – Easy Contact Form and Form Builder', 'accelerate' ),
					'slug'     => 'everest-forms/everest-forms.php',
					'required' => true,
				),
				'breadcrumb-navxt'   => array(
					'name' => __( 'Breadcrumb NavXT', 'accelerate' ),
					'slug' => 'breadcrumb-navxt/breadcrumb-navxt.php',
				),
				'woocommerce'        => array(
					'name' => __( 'WooCommerce', 'accelerate' ),
					'slug' => 'woocommerce/woocommerce.php',
				),
				'google-maps-widget' => array(
					'name' => __( 'Google Maps Widget', 'accelerate' ),
					'slug' => 'google-maps-widget/google-maps-widget.php',
				),
			),
		),
		'accelerate-free' => array(
			'name'                   => esc_html__( 'Accelerate', 'accelerate' ),
			'theme'                  => 'Accelerate Pro',
			'template'               => 'accelerate-pro',
			'demo_url'               => 'http://demo.themegrill.com/accelerate/',
			'demo_pack'              => false,
			'core_options'           => array(
				'blogname'       => 'Accelerate',
				'page_on_front'  => 'Business Page',
				'page_for_posts' => 'Blog',
			),
			'widgets_data_update'    => array(

				/**
				 * Dropdown Pages - Handles widgets Page ID.
				 *
				 * 1. accelerate_featured_single_page_widget
				 * 2. accelerate_image_service_widget
				 * 3. accelerate_recent_work_widget
				 */
				'dropdown_pages' => array(
					'accelerate_featured_single_page_widget' => array(
						2 => array(
							'page_id' => 'About Us',
						),
					),
					'accelerate_image_service_widget'        => array(
						2 => array(
							'page_id0' => 'Clean Code',
							'page_id1' => 'Cool Design',
							'page_id2' => 'Nice Support',
						),
					),
					'accelerate_recent_work_widget'          => array(
						3 => array(
							'page_id0' => 'Nice Shoes',
							'page_id1' => 'Sky Diving',
							'page_id2' => 'Jumping Girl',
							'page_id3' => 'Sea Diving',
						),
					),
				),
			),
			'customizer_data_update' => array(
				'nav_menu_locations' => array(
					'primary' => 'Primary',
					'footer'  => 'Footer',
				),
			),
			'plugins_list'           => array(
				'everest-forms'      => array(
					'name'     => 'Everest Forms – Easy Contact Form and Form Builder',
					'slug'     => 'everest-forms/everest-forms.php',
					'required' => true,
				),
				'breadcrumb-navxt'   => array(
					'name'     => 'Breadcrumb NavXT',
					'slug'     => 'breadcrumb-navxt/breadcrumb-navxt.php',
					'required' => false,
				),
				'google-maps-widget' => array(
					'name'     => 'Google Maps Widget',
					'slug'     => 'google-maps-widget/google-maps-widget.php',
					'required' => false,
				),
			),
		),
	);

	return array_merge( $new_demo_config, $demo_config );
}

add_filter( 'themegrill_demo_importer_config', 'accelerate_demo_importer_config' );

