/**
 * navigation.js
 *
 * Handles toggling the navigation menu for small screens.
 */
( function() {
	var container, button, menu;

	container = document.getElementById( 'site-navigation' );
	if ( ! container ) {
		return;
	}

	button = container.getElementsByTagName( 'h3' )[0];
	if ( 'undefined' === typeof button ) {
		return;
	}

	menu = container.getElementsByTagName( 'ul' )[0];

	// Hide menu toggle button if menu is empty and return early.
	if ( 'undefined' === typeof menu ) {
		button.style.display = 'none';
		return;
	}

	button.onclick = function() {
		if ( -1 !== container.className.indexOf( 'main-small-navigation' ) ) {
			container.className = container.className.replace( 'main-small-navigation', 'main-navigation' );
		} else {
			container.className = container.className.replace( 'main-navigation', 'main-small-navigation' );
		}
	};

	/**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( container ) {
        var touchStartFn, i,
            parentLink = container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, i;

                if ( ! menuItem.classList.contains( 'focus' ) ) {
                    e.preventDefault();
                    for ( i = 0; i < menuItem.parentNode.children.length; ++i ) {
                        if ( menuItem === menuItem.parentNode.children[i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[i].classList.remove( 'focus' );
                    }
                    menuItem.classList.add( 'focus' );
                } else {
                    menuItem.classList.remove( 'focus' );
                }
            };

            for ( i = 0; i < parentLink.length; ++i ) {
                parentLink[i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( container ) );
} )();

( function() {
	var container, button, menu;

	container = document.getElementById( 'top-site-navigation' );
	if ( ! container ) {
		return;
	}

	button = container.getElementsByTagName( 'h3' )[0];
	if ( 'undefined' === typeof button ) {
		return;
	}

	menu = container.getElementsByTagName( 'ul' )[0];

	// Hide menu toggle button if menu is empty and return early.
	if ( 'undefined' === typeof menu ) {
		button.style.display = 'none';
		return;
	}

	if ( -1 === menu.className.indexOf( 'nav-menu' ) ) {
		menu.className += 'nav-menu';
	}

	button.onclick = function() {
		if ( -1 !== container.className.indexOf( 'mobile-small-menu' ) ) {
			container.className = container.className.replace( 'mobile-small-menu', 'small-menu' );
		} else {
			container.className = container.className.replace( 'small-menu', 'mobile-small-menu' );
		}
	};
} )();

jQuery(document).ready(function() {
	/* New responsive menu */
    jQuery( '.better-responsive-menu #site-navigation .menu-item-has-children, .better-responsive-menu #site-navigation .page_item_has_children' ).append( '<span class="sub-toggle"> <i class="fa fa-caret-down"></i> </span>' );
    jQuery( '.better-responsive-menu #site-navigation .sub-toggle' ).click( function() {
    	// Hide opened siblings
    	jQuery(this).parent( '.menu-item-has-children, .page_item_has_children' )
    		.siblings( '.menu-item-has-children, .page_item_has_children' ).children( 'ul.sub-menu, ul.children' ).slideUp( '1000' );

        jQuery(this).parent( '.menu-item-has-children, .page_item_has_children' )
        	.children( 'ul.sub-menu, ul.children' ).first().slideToggle( '1000' );
        jQuery(this).children( '.fa-caret-down' ).first().toggleClass( 'fa-caret-up' );
    });
});
