<?php
/**
 * The Sidebar containing the footer widget areas.
 *
 * @package    ThemeGrill
 * @subpackage Accelerate Pro
 * @since      Accelerate Pro 1.0
 */

/**
 * The footer widget area is triggered if any of the areas
 * have widgets. So let's check that first.
 *
 * If none of the sidebars have widgets, then let's bail early.
 */
if ( ! is_active_sidebar( 'accelerate_footer_sidebar_one' ) &&
     ! is_active_sidebar( 'accelerate_footer_sidebar_two' ) &&
     ! is_active_sidebar( 'accelerate_footer_sidebar_three' ) &&
     ! is_active_sidebar( 'accelerate_footer_sidebar_four' ) ) {
	return;
}

// Assign the dynamic classes for the footer column select option
if ( accelerate_options( 'accelerate_footer_widget_column_select_type', 'three' ) == 'one' ) {
	$footer_column_one_class   = 'tg-column-full';
	$footer_column_two_class   = '';
	$footer_column_three_class = '';
	$footer_column_four_class  = '';
} else if ( accelerate_options( 'accelerate_footer_widget_column_select_type', 'three' ) == 'two' ) {
	$footer_column_one_class   = 'tg-one-half';
	$footer_column_two_class   = 'tg-one-half tg-one-half-last';
	$footer_column_three_class = '';
	$footer_column_four_class  = '';
} else if ( accelerate_options( 'accelerate_footer_widget_column_select_type', 'three' ) == 'three' ) {
	$footer_column_one_class   = 'tg-one-third';
	$footer_column_two_class   = 'tg-one-third';
	$footer_column_three_class = 'tg-one-third tg-one-third-last';
	$footer_column_four_class  = '';
} else if ( accelerate_options( 'accelerate_footer_widget_column_select_type', 'three' ) == 'four' ) {
	$footer_column_one_class   = 'tg-one-fourth tg-column-1';
	$footer_column_two_class   = 'tg-one-fourth tg-column-2';
	$footer_column_three_class = 'tg-one-fourth tg-after-two-blocks-clearfix tg-column-3';
	$footer_column_four_class  = 'tg-one-fourth tg-one-fourth-last tg-column-4';
}
?>
<div class="footer-widgets-wrapper">
	<div class="inner-wrap">
		<div class="footer-widgets-area clearfix">
			<div class="<?php echo esc_attr( $footer_column_one_class ); ?>">
				<?php
				if ( ! dynamic_sidebar( 'accelerate_footer_sidebar_one' ) ):
				endif;
				?>
			</div>

			<?php if ( $footer_column_two_class != '' ) : ?>
				<div class="<?php echo esc_attr( $footer_column_two_class ); ?>">
					<?php
					if ( ! dynamic_sidebar( 'accelerate_footer_sidebar_two' ) ):
					endif;
					?>
				</div>
			<?php endif; ?>

			<?php if ( $footer_column_three_class != '' ) : ?>
				<div class="<?php echo esc_attr( $footer_column_three_class ); ?>">
					<?php
					if ( ! dynamic_sidebar( 'accelerate_footer_sidebar_three' ) ):
					endif;
					?>
				</div>
			<?php endif; ?>

			<?php if ( $footer_column_four_class != '' ) : ?>
				<div class="<?php echo esc_attr( $footer_column_four_class ); ?>">
					<?php
					if ( ! dynamic_sidebar( 'accelerate_footer_sidebar_four' ) ):
					endif;
					?>
				</div>
			<?php endif; ?>
		</div>
	</div>
</div>
